// Copyright (c) 2009
// Utrecht University (The Netherlands),
// ETH Zurich (Switzerland),
// INRIA Sophia-Antipolis (France),
// Max-Planck-Institute Saarbruecken (Germany),
// and Tel-Aviv University (Israel).  All rights reserved.
//
// This file is part of CGAL (www.cgal.org)
//
// $URL: https://github.com/CGAL/cgal/blob/v5.5.2/Installation/include/CGAL/version.h $
// $Id: version.h 755bfe4 2022-10-12T15:30:32+02:00 Laurent Rineau
// SPDX-License-Identifier: LGPL-3.0-or-later OR LicenseRef-Commercial
//
// Author(s)     : -

#ifndef CGAL_VERSION_H
#define CGAL_VERSION_H

#ifndef SWIG
#define CGAL_VERSION 5.5.2
#define CGAL_GIT_HASH 8a3184a1a82c3e7d737656bfa4950471c369a4b9
#endif
#define CGAL_VERSION_NR 1050521000
#define CGAL_SVN_REVISION 99999
#define CGAL_RELEASE_DATE 20230224

#include <CGAL/version_macros.h>

#endif
